@@ -1,4 +1,6 @@
-from .tracking import AbstractCreateUpdateTime, AbstractCreateUpdateUser, AbstractDeleteTime, AbstractDeleteUser
+from .tracking import (
+    AbstractCreateUpdateTime, AbstractCreateUpdateUser, AbstractDeleteTime, AbstractDeleteUser, AbstractFullTracking
+)
 from .uuid import AbstractUUID, AbstractUUIDAsPK
 from .slug import AbstractUniqueNameSlug
 from .fk import AbstractForeignKeySelect
